Strategies — hermes 0.1 documentation

# Strategies

class `hermes.strategies.` `AbstractErrorStrategy`

  Abstract strategy for handling errors returned from components

  `handle_exception`(error)

    An abstract method that must be overidden by subclasses.

    Must return a tuple of: (Boolean indicating if the exception was expected, a string message)

class `hermes.strategies.` `CommonErrorStrategy`

  A common error strategy to deal with Postgres errors